#
# spec file for package python-numpy
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global flavor standard%{nil}

%define ver 1.16.1
%define _ver 1_16_1
%define pname python-numpy

%bcond_with ringdisabled

%define hpc_upcase_trans_hyph() %(echo %{**} | tr [a-z] [A-Z] | tr '-' '_')

%if "%flavor" == ""
ExclusiveArch:  do_not_build
%endif

%if "%flavor" == "standard"
 %bcond_with hpc
 %ifarch armv6l s390 s390x
  %bcond_with openblas
 %else
  %bcond_without openblas
 %endif
%endif

%if "%flavor" == "gnu-hpc"
 %bcond_without hpc
%endif

%if "%flavor" == "gnu7-hpc"
 %bcond_without hpc
 %define c_f_ver 7
%endif

%ifarch s390
%{?with_openblas:ExclusiveArch:  do_not_build}
%endif

%if %{without hpc}
%define package_name %{pname}
%define p_python_sitearch %python_sitearch
%define p_prefix %_prefix
%define p_bindir %_bindir
%else
# Magic for OBS Staging. Only build the flavors required by
# other packages in the ring.
%if %{with ringdisabled}
ExclusiveArch:  do_not_build
%endif
%{!?compiler_family:%global compiler_family gnu}
%{hpc_init -c %compiler_family %{?c_f_ver:-v %{c_f_ver}} %{?mpi_ver:-V %{mpi_ver}}}
%define package_name %{hpc_package_name %_ver}
%define p_python_sitearch %hpc_python_sitearch
%define p_prefix %hpc_prefix
%define p_bindir %hpc_bindir
%endif

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           %{package_name}
Version:        %ver
Release:        lp151.5.3.1
Summary:        NumPy array processing for numbers, strings, records and objects
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            http://www.numpy.org/
Source:         https://pypi.io/packages/source/n/numpy/numpy-%{version}.zip
# PATCH-FIX-OPENSUSE numpy-buildfix.patch -- openSUSE-specific build fixes
Patch0:         numpy-buildfix.patch
# PATCH-FIX-OPENSUSE numpy-1.9.0-remove-__declspec.patch -- fix for spurious compiler warnings that cause build failure
Patch1:         numpy-1.9.0-remove-__declspec.patch
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
%if %{without hpc}
 %if 0%{?suse_version}
BuildRequires:  gcc-fortran
 %else
BuildRequires:  gcc-gfortran
 %endif
 %if %{with openblas}
BuildRequires:  openblas-devel
 %else
BuildRequires:  blas-devel
BuildRequires:  lapack-devel
 %endif
%else
BuildRequires:  %{compiler_family}%{?c_f_ver}-compilers-hpc-macros-devel
BuildRequires:  libopenblas%{?hpc_ext}-%{compiler_family}%{?c_f_ver}-hpc-devel
BuildRequires:  lua-lmod
BuildRequires:  suse-hpc
Requires:       libopenblas%{?hpc_ext}-%{compiler_family}%{?c_f_ver}-hpc
%endif
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
%{?with_hpc:%{hpc_requires}}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%python_subpackages

%description
NumPy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays.  NumPy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type which also makes NumPy suitable for
interfacing with general-purpose data-base applications.

There are also basic facilities for discrete fourier transform,
basic linear algebra and random number generation.

%{?with_hpc:%{hpc_python_master_package -L -a }}

%package devel
Summary:        Development files for numpy applications
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python-devel
%if %{without hpc}
 %if %{with openblas}
Requires:       openblas-devel
 %else
Requires:       blas-devel
Requires:       lapack-devel
 %endif
%else
Requires:       libopenblas%{?hpc_ext}-%{compiler_family}%{?c_f_ver}-hpc-devel
%hpc_requires_devel
%endif

%description devel
This package contains files for developing applications using numpy.

%{?with_hpc:%{hpc_python_master_package devel -a }}

%prep
%setup -q -n numpy-%{version}
%patch0 -p1
%patch1 -p1
# Fix non-executable scripts
sed -i '1s/^#!.*$//' numpy/{compat/setup,distutils/{conv_template,cpuinfo,exec_command,from_template,setup,system_info},f2py/{__init__,auxfuncs,capi_maps,cb_rules,cfuncs,common_rules,crackfortran,diagnose,f2py2e,f90mod_rules,func2subr,rules,setup,use_rules},ma/setup,matrixlib/setup,setup,testing/{print_coercion_tables,setup}}.py

%build
%if %{with hpc}
%hpc_setup
module load openblas
export CFLAGS="$(pkg-config --cflags openblas) %{optflags} -fno-strict-aliasing" LIBS="$(pkg-config --libs openblas)"
cat > site.cfg <<EOF
[openblas]
libraries = openblas
library_dirs = $OPENBLAS_LIB
include_dirs = $OPENBLAS_INC
EOF
%else
export CFLAGS="%{optflags} -fno-strict-aliasing"
%endif

%python_build

%install
%{?with_hpc:%{hpc_setup}}
%{?with_hpc:module load openblas}

%python_exec setup.py install --prefix=%{p_prefix} --root=%{buildroot}

%if 0%{?suse_version}
%fdupes %{buildroot}%{p_prefix}
%endif

%if %{without hpc}

%python_expand rm -rf %{buildroot}%{$python_sitearch}/numpy/{,core,distutils,f2py,fft,lib,linalg,ma,matrixlib,oldnumeric,polynomial,random,testing}/tests # Don't package testsuite

%else

%define hpc_module_pname python${py_ver/.*/}-numpy
%{python_expand # Don't package testsuite
py_ver=%{$python_version}
sitesearch_path=`$python -c "import sysconfig as s; print(s.get_paths(vars={'platbase':'%{hpc_prefix}','base':'%{hpc_prefix}'}).get('platlib'))"`
rm -rf %{buildroot}${sitesearch_path}/numpy/{,core,distutils,f2py,fft,lib,linalg,ma,matrixlib,oldnumeric,polynomial,random,testing}/tests
%hpc_write_modules_files
#%%Module1.0#####################################################################

proc ModulesHelp { } {

puts stderr " "
puts stderr "This module loads the %{pname} library built with the %{compiler_family} compiler"
puts stderr "toolchain."
puts stderr "\nVersion %{version}\n"

}
module-whatis "Name: %{pname} built with %{compiler_family} compiler"
module-whatis "Version: %{version}"
module-whatis "Category: python module"
module-whatis "Description: %{SUMMARY:0}"
module-whatis "URL %{url}"

set     version             %{version}

if [ expr [ module-info mode load ] || [module-info mode display ] ] {
  if { ![is-loaded intel] && ![is-loaded openblas] } {
      module load openblas
    }
}

prepend-path    PATH                %{hpc_bindir}
prepend-path    PYTHONPATH          ${sitesearch_path}

setenv          %{hpc_upcase_trans_hyph %pname}_DIR        %{hpc_prefix}
setenv          %{hpc_upcase_trans_hyph %pname}_BIN        %{hpc_bindir}

family "NumPy"
EOF
}
%endif

%files %{python_files}
%defattr(-,root,root)
%doc *.txt
%python2_only %{p_bindir}/f2py%{python2_bin_suffix}
%python2_only %{p_bindir}/f2py2
%python3_only %{p_bindir}/f2py
%python3_only %{p_bindir}/f2py%{python3_bin_suffix}
%python3_only %{p_bindir}/f2py3
%{p_python_sitearch}/numpy/
%{p_python_sitearch}/numpy-%{version}-py*.egg-info
%exclude %{p_python_sitearch}/numpy/*/*/*.c
%exclude %{p_python_sitearch}/numpy/*/*.h
%exclude %{p_python_sitearch}/numpy/*/*/*.h
%exclude %{p_python_sitearch}/numpy/*/*/*/*.h
%exclude %{p_python_sitearch}/numpy/core/lib/libnpymath.a

%if %{with hpc}
%define hpc_module_pname python%(a=%{hpc_python_version}; echo -n ${a/.*/})-numpy
%{hpc_modules_files}
%{hpc_dirs}
%dir %hpc_bindir
%dir %{hpc_libdir}/python%{hpc_python_version}
%dir %{p_python_sitearch}
%endif

%files %{python_files devel}
%defattr(-,root,root)
%license LICENSE.txt
%{p_python_sitearch}/numpy/*/*/*.c
%{p_python_sitearch}/numpy/*/*.h
%{p_python_sitearch}/numpy/*/*/*.h
%{p_python_sitearch}/numpy/*/*/*/*.h
%{p_python_sitearch}/numpy/core/lib/libnpymath.a

%changelog
* Wed Aug 28 2019 Matej Cepl <mcepl@suse.com>
- (jsc#SLE-8532, bsc#1149203) Update to 1.16.1:
  - The NumPy 1.16.1 release fixes bugs reported against the
    1.16.0 release, and also backports several enhancements from
    master that seem appropriate for a release series that is the
    last to support Python 2.7. The wheels on PyPI are linked
    with OpenBLAS v0.3.4+, which should fix the known threading
    issues found in previous OpenBLAS versions.
  - Specifically:
  - Experimental (opt-in only) support for overriding numpy
    functions, see __array_function__ below.
  - The matmul function is now a ufunc. This provides better
    performance and allows overriding with __array_ufunc__.
  - Improved support for the ARM and POWER architectures.
  - Improved support for AIX and PyPy.
  - Improved interop with ctypes.
  - Improved support for PEP 3118.
  - Also includes all improvements to 1.15.*, namely:
  - NumPy has switched to pytest for testing.
  - A new numpy.printoptions context manager.
  - Many improvements to the histogram functions.
  - Support for unicode field names in python 2.7.
  - Improved support for PyPy.
  - Fixes and improvements to numpy.einsum.
- Removed CVE-2019-6446_numpy_load.patch, which is included into
  the upstream release.
- numpy-1.9.0-remove-__declspec.patch has been refreshed to fit
  the current upstream tarball.
* Mon Feb  4 2019 Matej Cepl <mcepl@suse.com>
- bsc#1122208 add CVE-2019-6446_numpy_load.patch fixing gh#numpy/numpy#12759
  numpy.load() has functionality which allows loading pickle with
  potentially insecure code.
* Fri Feb  9 2018 cgoll@suse.com
- Fix summary in module files (bnc#1080259)
* Tue Feb  6 2018 eich@suse.com
- The HPC of python-numpy expects openBLAS. OpenBLAS is not availble
  for sc390: disable buidling on s390 for HPC (bsc#1079513).
* Fri Jan 19 2018 ro@suse.de
- add s390 to the ifarch conditional to build without openblas
* Wed Jan 10 2018 adrian@suse.de
- update to version 1.14.0
  Changes documented in release notes:
  https://github.com/numpy/numpy/blob/master/doc/release/1.14.0-notes.rst
* Fri Jan  5 2018 eich@suse.com
- Switch from gcc6 to gcc7 as additional compiler flavor for HPC on SLES.
- Fix library package requires - use HPC macro (boo#1074890).
* Mon Nov 13 2017 eich@suse.com
- Add 'family "NumPy"' to modules file to avoid that different
  versions of this get loaded.
* Sun Nov 12 2017 eich@suse.com
- Add Requires for libopenblas to base package.
- Add Requires for lua-lmod
- Fix '-' in environment variable mane of modulefile.
* Mon Oct 30 2017 eich@suse.com
- Fix Requires: of devel package for openblas.
* Tue Oct 17 2017 eich@suse.com
- Add magic to limit the number of flavors built in the OBS ring
  to non-HPC builds.
* Tue Oct  3 2017 eich@suse.com
- Convert to multibuild: Add support for HPC environment modules
  (FATE#321709).
* Sat Sep 30 2017 arun@gmx.de
- updated line numbers in patches
- update to version 1.13.3:
  * #9390 BUG: Return the poly1d coefficients array directly
  * #9555 BUG: Fix regression in 1.13.x in distutils.mingw32ccompiler.
  * #9556 BUG: Fix true_divide when dtype=np.float64 specified.
  * #9557 DOC: Fix some rst markup in numpy/doc/basics.py.
  * #9558 BLD: Remove -xhost flag from IntelFCompiler.
  * #9559 DOC: Removes broken docstring example (source code, png,
    pdf)...
  * #9580 BUG: Add hypot and cabs functions to WIN32 blacklist.
  * #9732 BUG: Make scalar function elision check if temp is
    writeable.
  * #9736 BUG: Various fixes to np.gradient
  * #9742 BUG: Fix np.pad for CVE-2017-12852 (bsc#1053963)
  * #9744 BUG: Check for exception in sort functions, add tests
  * #9745 DOC: Add whitespace after "versionadded::" directive so it
    actually...
  * #9746 BUG: Memory leak in np.dot of size 0
  * #9747 BUG: Adjust gfortran version search regex
  * #9757 BUG: Cython 0.27 breaks NumPy on Python 3.
  * #9764 BUG: Ensure _npy_scaled_cexp{,f,l} is defined when needed.
  * #9765 BUG: PyArray_CountNonzero does not check for exceptions
  * #9766 BUG: Fixes histogram monotonicity check for unsigned bin
    values
  * #9767 BUG: Ensure consistent result dtype of count_nonzero
  * #9771 BUG: MAINT: Fix mtrand for Cython 0.27.
  * #9772 DOC: Create the 1.13.2 release notes.
  * #9794 DOC: Create 1.13.3 release notes.
- changes from version 1.13.2:
  * #9390 BUG: Return the poly1d coefficients array directly
  * #9555 BUG: Fix regression in 1.13.x in distutils.mingw32ccompiler.
  * #9556 BUG: Fix true_divide when dtype=np.float64 specified.
  * #9557 DOC: Fix some rst markup in numpy/doc/basics.py.
  * #9558 BLD: Remove -xhost flag from IntelFCompiler.
  * #9559 DOC: Removes broken docstring example (source code, png,
    pdf)...
  * #9580 BUG: Add hypot and cabs functions to WIN32 blacklist.
  * #9732 BUG: Make scalar function elision check if temp is
    writeable.
  * #9736 BUG: Various fixes to np.gradient
  * #9742 BUG: Fix np.pad for CVE-2017-12852 (bsc#1053963)
  * #9744 BUG: Check for exception in sort functions, add tests
  * #9745 DOC: Add whitespace after "versionadded::" directive so it
    actually...
  * #9746 BUG: Memory leak in np.dot of size 0
  * #9747 BUG: Adjust gfortran version search regex
  * #9757 BUG: Cython 0.27 breaks NumPy on Python 3.
  * #9764 BUG: Ensure _npy_scaled_cexp{,f,l} is defined when needed.
  * #9765 BUG: PyArray_CountNonzero does not check for exceptions
  * #9766 BUG: Fixes histogram monotonicity check for unsigned bin
    values
  * #9767 BUG: Ensure consistent result dtype of count_nonzero
  * #9771 BUG, MAINT: Fix mtrand for Cython 0.27.
* Mon Sep 18 2017 hsk17@mail.de
- Update to version 1.13.1
  * bugfix release for problems found in 1.13.0; major changes:
    + fixes for the new memory overlap detection and temporary
    elision
    + reversion of the removal of the boolean binary - operator
  * 1.13.0 Highlights:
    + Operations like a + b + c will reuse temporaries on some
    platforms
    + Inplace operations check if inputs overlap outputs and
    create temporaries
    + New __array_ufunc__ attribute provides improved ability for
    classes to override default ufunc behavior.
    + New np.block function for creating blocked arrays.
  * 1.13.0 New functions:
    + New np.positive ufunc.
    + New np.divmod ufunc provides more efficient divmod.
    + New np.isnat ufunc tests for NaT special values.
    + New np.heaviside ufunc computes the Heaviside function.
    + New np.isin function, improves on in1d.
    + New np.block function for creating blocked arrays.
    + New PyArray_MapIterArrayCopyIfOverlap added to NumPy C-API.
  * deprecations, compatibility notes, etc see full changelog at
    https://github.com/numpy/numpy/blob/master/doc/changelog/1.13.0-changelog.rst
- dropped xlocale.patch (now upstream)
- do not apply 'sed 1d' command to exec_command.py
* Wed Jul  5 2017 schwab@suse.de
- Add xlocale.patch:
  xlocale.h: don't use obsolete <xlocale.h>
* Tue Jun  6 2017 manfred99@gmx.ch
- allow building numpy on fedora by making fdupes dependency optional
* Thu Apr  6 2017 toddrme2178@gmail.com
- Update to version 1.12.1
  * Fix wrong future nat warning and equiv type logic error...
  * Fix wrong masked median for some special cases
  * Place np.average in inline code
  * Work around isfinite inconsistency on i386
  * Guard against replacing constants without '_' spec in f2py.
  * Fix mean for float 16 non-array inputs for 1.12
  * Fix calling python api with error set and minor leaks for...
  * Make iscomplexobj compatible with custom dtypes again
  * Fix undefined behaviour induced by bad __array_wrap__
  * Fix MaskedArray.__setitem__
  * PPC64el machines are POWER for Fortran in f2py
  * Look up methods on MaskedArray in `_frommethod`
  * Remove extra digit in binary_repr at limit
  * Fix deepcopy regression for empty arrays.
  * Fix ma.median for empty ndarrays
- Further updates to macro usage.
* Mon Feb 27 2017 toddrme2178@gmail.com
- Fix macro usage.
* Thu Feb 23 2017 toddrme2178@gmail.com
- Fix -devel package dependency
* Fri Feb 17 2017 toddrme2178@gmail.com
- Switch to single-spec version
* Tue Jan 17 2017 toddrme2178@gmail.com
- update to version 1.12.0:
  * Highlights
    + Order of operations in np.einsum can now be optimized for large
    speed improvements.
    + New signature argument to np.vectorize for vectorizing with core
    dimensions.
    + The keepdims argument was added to many functions.
    + New context manager for testing warnings
    + Support for BLIS in numpy.distutils
    + Much improved support for PyPy (not yet finished)
  * full changelog at:
    https://github.com/numpy/numpy/blob/master/doc/release/1.12.0-notes.rst
- changes from version 1.11.3:
  * #8341: BUG: Fix ndarray.tofile large file corruption in append
    mode.
  * #8346: TST: Fix tests in PR #8341 for NumPy 1.11.x
- update to version 1.11.2:
  * #7736 BUG: Many functions silently drop 'keepdims' kwarg.
  * #7738 ENH: Add extra kwargs and update doc of many MA methods.
  * #7778 DOC: Update Numpy 1.11.1 release notes.
  * #7793 BUG: MaskedArray.count treats negative axes incorrectly.
  * #7816 BUG: Fix array too big error for wide dtypes.
  * #7821 BUG: Make sure npy_mul_with_overflow_<type> detects
    overflow.
  * #7824 MAINT: Allocate fewer bytes for empty arrays.
  * #7847 MAINT,DOC: Fix some imp module uses and update f2py.compile
    docstring.
  * #7849 MAINT: Fix remaining uses of deprecated Python imp module.
  * #7851 BLD: Fix ATLAS version detection.
  * #7896 BUG: Construct ma.array from np.array which contains
    padding.
  * #7904 BUG: Fix float16 type not being called due to wrong
    ordering.
  * #7917 BUG: Production install of numpy should not require nose.
  * #7919 BLD: Fixed MKL detection for recent versions of this
    library.
  * #7920 BUG: Fix for issue #7835 (ma.median of 1d).
  * #7932 BUG: Monkey-patch _msvccompile.gen_lib_option like other
    compilers.
  * #7939 BUG: Check for HAVE_LDOUBLE_DOUBLE_DOUBLE_LE in
    npy_math_complex.
  * #7953 BUG: Guard against buggy comparisons in generic quicksort.
  * #7954 BUG: Use keyword arguments to initialize Extension base
    class.
  * #7955 BUG: Make sure numpy globals keep identity after reload.
  * #7972 BUG: MSVCCompiler grows 'lib' & 'include' env strings
    exponentially.
  * #8005 BLD: Remove __NUMPY_SETUP__ from builtins at end of
    setup.py.
  * #8010 MAINT: Remove leftover imp module imports.
  * #8020 BUG: Fix return of np.ma.count if keepdims is True and axis
    is None.
  * #8024 BUG: Fix numpy.ma.median.
  * #8031 BUG: Fix np.ma.median with only one non-masked value.
  * #8044 BUG: Fix bug in NpyIter buffering with discontinuous arrays.
- update copyright year
- changed from tar.gz to zip on pypi
- Remove long-unused atlas support.
- Use preferrered pypi.io download url.
- Add openBLAS support.
  This can improve performance in many situations.
- Remove numpy-1.10.4-cblas.patch since openblas handles this.
* Tue Nov 22 2016 toddrme2178@gmail.com
- Fix cblas handling for SLES 12.
* Mon Sep 12 2016 dmueller@suse.com
- use pypi.io as Source URL
* Tue Sep  6 2016 jweberhofer@weberhofer.at
- Don't include cblas-devel on SLES 12
* Fri Jul  8 2016 dmueller@suse.com
- update to 1.11.1:
  - #7506 BUG: Make sure numpy imports on python 2.6 when nose is unavailable.
  - #7530 BUG: Floating exception with invalid axis in np.lexsort.
  - #7535 BUG: Extend glibc complex trig functions blacklist to glibc < 2.18.
  - #7551 BUG: Allow graceful recovery for no compiler.
  - #7558 BUG: Constant padding expected wrong type in constant_values.
  - #7578 BUG: Fix OverflowError in Python 3.x. in swig interface.
  - #7590 BLD: Fix configparser.InterpolationSyntaxError.
  - #7597 BUG: Make np.ma.take work on scalars.
  - #7608 BUG: linalg.norm(): Don't convert object arrays to float.
  - #7638 BLD: Correct C compiler customization in system_info.py.
  - #7654 BUG: ma.median of 1d array should return a scalar.
  - #7656 BLD: Remove hardcoded Intel compiler flag -xSSE4.2.
  - #7660 BUG: Temporary fix for str(mvoid) for object field types.
  - #7665 BUG: Fix incorrect printing of 1D masked arrays.
  - #7670 BUG: Correct initial index estimate in histogram.
  - #7671 BUG: Boolean assignment no GIL release when transfer needs API.
  - #7676 BUG: Fix handling of right edge of final histogram bin.
  - #7680 BUG: Fix np.clip bug NaN handling for Visual Studio 2015.
  - #7724 BUG: Fix segfaults in np.random.shuffle.
  - #7731 MAINT: Change mkl_info.dir_env_var from MKL to MKLROOT.
* Mon Apr  4 2016 toddrme2178@gmail.com
  specfile:
  * require setuptools
- update to version 1.11.0:
  * Highlights
    + The datetime64 type is now timezone naive.
    + A dtype parameter has been added to randint.
    + Improved detection of two arrays possibly sharing memory.
    + Automatic bin size estimation for np.histogram.
    + Speed optimization of A @ A.T and dot(A, A.T).
    + New function np.moveaxis for reordering array axes.
  * full changelog at https://github.com/numpy/numpy/blob/master/doc/release/1.11.0-notes.rst
* Wed Mar 30 2016 stecue@gmail.com
- Add numpy-1.10.4-cblas.patch to build against system cblas.
  Numpy assumes either libblas.so or libcblas.so to contain all CBLAS
  and BLAS functions. However the cblas-devel in Leap and Tumbleweed
  contains only the CBLAS interface and libblas.so is also needed.
* Fri Jan  8 2016 toddrme2178@gmail.com
- update to version 1.10.4:
  * see https://github.com/numpy/numpy/blob/master/doc/release/1.10.4-notes.rst
  * There is no 1.10.3 due to packaging issues.
- update to version 1.10.2:
  * see https://github.com/numpy/numpy/blob/master/doc/release/1.10.2-notes.rst
* Tue Oct 13 2015 toddrme2178@gmail.com
- Update to 1.10.1
  + Bugfix for build problems
  * Compiling with msvc9 or msvc10 for 32 bit Windows now requires SSE2.
    This was the easiest fix for what looked to be some miscompiled code when
    SSE2 was not used. If you need to compile for 32 bit Windows systems
    without SSE2 support, mingw32 should still work.
  * Make compiling with VS2008 python2.7 SDK easier
  * Change Intel compiler options so that code will also be generated to
    support systems without SSE4.2.
  * Some _config test functions needed an explicit integer return in
    order to avoid the openSUSE rpmlinter erring out.
  * We ran into a problem with pipy not allowing reuse of filenames and a
    resulting proliferation of *.*.*.postN releases. Not only were the names
    getting out of hand, some packages were unable to work with the postN
    suffix.
- Remove upstream-included numpy-1.10.0-remove_Wreturn_type_warnings.patch
* Tue Oct  6 2015 toddrme2178@gmail.com
- Update to version 1.10.0
  + Highlights
  * numpy.distutils now supports parallel compilation via the --parallel/-j
    argument passed to setup.py build
  * numpy.distutils now supports additional customization via site.cfg to
    control compilation parameters, i.e. runtime libraries, extra
    linking/compilation flags.
  * Addition of *np.linalg.multi_dot*: compute the dot product of two or more
    arrays in a single function call, while automatically selecting the
    fastest evaluation order.
  * The new function `np.stack` provides a general interface for joining a
    sequence of arrays along a new axis, complementing `np.concatenate` for
    joining along an existing axis.
  * Addition of `nanprod` to the set of nanfunctions.
  * Support for the '@' operator in Python 3.5.
  + Dropped Support:
  * The _dotblas module has been removed. CBLAS Support is now in
    Multiarray.
  * The testcalcs.py file has been removed.
  * The polytemplate.py file has been removed.
  * npy_PyFile_Dup and npy_PyFile_DupClose have been removed from
    npy_3kcompat.h.
  * splitcmdline has been removed from numpy/distutils/exec_command.py.
  * try_run and get_output have been removed from
    numpy/distutils/command/config.py
  * The a._format attribute is no longer supported for array printing.
  * Keywords ``skiprows`` and ``missing`` removed from np.genfromtxt.
  * Keyword ``old_behavior`` removed from np.correlate.
  + Future Changes:
  * In array comparisons like ``arr1 == arr2``, many corner cases
    involving strings or structured dtypes that used to return scalars
    now issue ``FutureWarning`` or ``DeprecationWarning``, and in the
    future will be change to either perform elementwise comparisons or
    raise an error.
  * The SafeEval class will be removed.
  * The alterdot and restoredot functions will be removed.
- Rebase numpy-1.9.0-remove-__declspec.patch
- Add numpy-1.10.0-remove_Wreturn_type_warnings.patch
  This patch is already merged upstream and should be present in
  numpy-1.10.1
* Wed Sep 23 2015 toddrme2178@gmail.com
- update to version 1.9.3:
  * #5866: fix error finding Python headers when build_ext --include-dirs is set;
  * #6016: fix np.loadtxt error on Python 3.5 when reading from gzip files;
  * #5555: Replace deprecated options for ifort;
  * #6096: remove /GL for VS2015 in check_long_double_representation;
  * #6141: enable Visual Studio 2015 C99 features;
  * #6171: revert C99 complex for MSVC14.
* Mon Mar  2 2015 toddrme2178@gmail.com
- Update to 1.9.2: Bugfix release
  * #5316: fix too large dtype alignment of strings and complex types
  * #5424: fix ma.median when used on ndarrays
  * #5481: Fix astype for structured array fields of different byte order
  * #5354: fix segfault when clipping complex arrays
  * #5524: allow np.argpartition on non ndarrays
  * #5612: Fixes ndarray.fill to accept full range of uint64
  * #5155: Fix loadtxt with comments=None and a string None data
  * #4476: Masked array view fails if structured dtype has datetime component
  * #5388: Make RandomState.set_state and RandomState.get_state threadsafe
  * #5390: make seed, randint and shuffle threadsafe
  * #5374: Fixed incorrect assert_array_almost_equal_nulp documentation
  * #5393: Add support for ATLAS > 3.9.33.
  * #5313: PyArray_AsCArray caused segfault for 3d arrays
  * #5492: handle out of memory in rfftf
  * #4181: fix a few bugs in the random.pareto docstring
  * #5359: minor changes to linspace docstring
  * #4723: fix a compile issues on AIX
* Thu Nov  6 2014 toddrme2178@gmail.com
- Update to 1.9.1: Bugfix release
  * gh-5184: restore linear edge behaviour of gradient to as it was in < 1.9.
    The second order behaviour is available via the `edge_order` keyword
  * gh-4007: workaround Accelerate sgemv crash on OSX 10.9
  * gh-5100: restore object dtype inference from iterable objects without
    `len()`
  * gh-5163: avoid gcc-4.1.2 (red hat 5) miscompilation causing a crash
  * gh-5138: fix nanmedian on arrays containing inf
  * gh-5203: copy inherited masks in MaskedArray.__array_finalize__
  * gh-2317: genfromtxt did not handle filling_values=0 correctly
  * gh-5067: restore api of npy_PyFile_DupClose in python2
  * gh-5063: cannot convert invalid sequence index to tuple
  * gh-5082: Segmentation fault with argmin() on unicode arrays
  * gh-5095: don't propagate subtypes from np.where
  * gh-5104: np.inner segfaults with SciPy's sparse matrices
  * gh-5136: Import dummy_threading if importing threading fails
  * gh-5148: Make numpy import when run with Python flag '-OO'
  * gh-5147: Einsum double contraction in particular order causes ValueError
  * gh-479: Make f2py work with intent(in out)
  * gh-5170: Make python2 .npy files readable in python3
  * gh-5027: Use 'll' as the default length specifier for long long
  * gh-4896: fix build error with MSVC 2013 caused by C99 complex support
  * gh-4465: Make PyArray_PutTo respect writeable flag
  * gh-5225: fix crash when using arange on datetime without dtype set
  * gh-5231: fix build in c99 mode
* Mon Sep  8 2014 toddrme2178@gmail.com
- Update to 1.9.0
  Highlights
  * Numerous performance improvements in various areas, most
    notably indexing and operations on small arrays are
    significantly faster. Indexing operations now also release the
    GIL.
  * Addition of nanmedian and nanpercentile rounds out the
    nanfunction set.
- Remove upstreamed numpy-double-double-le.patch
- Add numpy-1.9.0-remove-__declspec.patch
  Fixes spurious warnings during build.  These warnings are related
  to a windows-specific function that is not built, so the patch
  just removed the function.
  See:
  http://lists.opensuse.org/opensuse-packaging/2014-09/msg00004.html
- Added patch tag for numpy-buildfix.patch
* Mon Aug 11 2014 toddrme2178@gmail.com
- Update to 1.8.2: Bugfix release
  * gh-4836: partition produces wrong results for multiple selections in equal ranges
  * gh-4656: Make fftpack._raw_fft threadsafe
  * gh-4628: incorrect argument order to _copyto in in np.nanmax, np.nanmin
  * gh-4642: Hold GIL for converting dtypes types with fields
  * gh-4733: fix np.linalg.svd(b, compute_uv=False)
  * gh-4853: avoid unaligned simd load on reductions on i386
  * gh-4722: Fix seg fault converting empty string to object
  * gh-4613: Fix lack of NULL check in array_richcompare
  * gh-4774: avoid unaligned access for strided byteswap
  * gh-650: Prevent division by zero when creating arrays from some buffers
  * gh-4602: ifort has issues with optimization flag O2, use O1
- Switch to pypi download location
- Changed Url to current home page
- Minor spec file cleanups
* Mon Apr 14 2014 arun@gmx.de
- bugfix release 1.8.1
* Thu Dec  5 2013 mls@suse.de
- add numpy-double-double-le.patch for ppc64le
* Thu Oct 31 2013 toddrme2178@gmail.com
- Update to 1.8.0
  Highlights:
  * New, no 2to3, Python 2 and Python 3 are supported by a common code base.
  * New, gufuncs for linear algebra, enabling operations on stacked arrays.
  * New, inplace fancy indexing for ufuncs with the ``.at`` method.
  * New, ``partition`` function, partial sorting via selection for fast median.
  * New, ``nanmean``, ``nanvar``, and ``nanstd`` functions skipping NaNs.
  * New, ``full`` and ``full_like`` functions to create value initialized arrays.
  * New, ``PyUFunc_RegisterLoopForDescr``, better ufunc support for user dtypes.
  * Numerous performance improvements in many areas.
- Add a new flag to easily enable/disable atlas support for if it
  ever gets fixed in the future
- Rebase numpy-buildfix.patch
* Sat May  4 2013 toddrme2178@gmail.com
- Update to 1.7.1
  * Bugfixes
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Mar 12 2013 highwaystar.ru@gmail.com
- update to 1.7.0
  * This release includes several new features as well as numerous
  bug fixes and refactorings
  Highlights:
  - ``where=`` parameter to ufuncs (allows the use of boolean
  arrays to choose where a computation should be done)
  - ``vectorize`` improvements (added 'excluded' and 'cache'
  keyword, general cleanup and bug fixes)
  - ``numpy.random.choice`` (random sample generating function)
  New Features:
  - Reduction UFuncs Generalize axis= Parameter
  - Reduction UFuncs New keepdims= Parameter
  - Datetime support
  - Custom formatter for printing arrays
  - New function numpy.random.choice
  - New function isclose
  - Preliminary multi-dimensional support in the polynomial package
  - Ability to pad rank-n arrays
  - New argument to searchsorted
  - Added experimental support for the AArch64 architecture.
  * For additional details check release notes at
  http://sourceforge.net/projects/numpy/files/NumPy/1.7.0/
- numpy-aarch64.diff: removed, now upstream
* Wed Mar  6 2013 dmueller@suse.com
- add numpy-aarch64.diff:
  * Fix build for AArch64
* Fri Aug 17 2012 toddrme2178@gmail.com
- Disable atlas buildrequires until the problems with atlas are
  worked out
* Mon Jun  4 2012 toddrme2178@gmail.com
- Add libatlas2 buildrequires
* Fri Jun  1 2012 toddrme2178@gmail.com
- Remove blas/lapack tests since these build successfully on all
  targets now
- Add documentation packages
  These are separate packages because a lot of packages depend on
  numpy, so building the documentation inside the base spec file
  would slow down the build process for the entire project
* Fri Jun  1 2012 kukuk@suse.de
- Old products don't provide python(abi).
* Mon May 21 2012 toddrme2178@gmail.com
- Update to version 1.6.2:
  * bugfixes
* Fri May 18 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
* Mon Apr 30 2012 toddrme2178@gmail.com
- Removed tests for unsupported openSUSE versions
* Mon Apr 23 2012 toddrme2178@gmail.com
- Add python 3 package
- devel package BuildRequires -> Requires
* Sun Apr 15 2012 idonmez@suse.com
- Fix SLE_11 build
* Fri Apr 13 2012 badshah400@gmail.com
- Modify BuildRequires to match recent name changes of lapack and
  blas in project.
* Sat Oct  1 2011 behrisch@users.sf.net
- Added static lib to devel package for scipy build
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 1.6.1:
  * Please see http://downloads.sourceforge.net/project/numpy/NumPy/1.6.1/Changelog
- Spec file cleanup:
  * Set license to BSD-3-Clause (SPDX style)
  * Removed testsuite from packages
  * Removed rpmlintrc file and actually fixed the issues
* Sun Jan 23 2011 toddrme2178@gmail.com
- update to 1.5.1
  Numpy 1.5.1 is a bug-fix release with no new
  features compared to 1.5.0.
  Relevant bugs fixed:
  * linalg: lstsq should always return real residual
  * lib: fix negative indices in s_ and index_exp
  * core: fix uint64 -> Python int cast
  * core: richcompare should return Py_NotImplemented when undefined
  * lib: close file handles after use in numpy.lib.npyio.*
  * core: ensure PEP 3118 buffers can be released in exception handler
  * core: fix clongdouble cast to Python complex()
  * core: fix detection for ``isfinite`` routine
* Mon Sep  6 2010 coolo@novell.com
- update to 1.5.0 to fix build against python 2.7
  highlights 1.3 -> 1.4:
  * New datetime dtype support to deal with dates in arrays
  * Faster import time
  * Extended array wrapping mechanism for ufuncs
  * New Neighborhood iterator (C-level only)
  * C99-like complex functions in npymath
  highlights 1.4 -> 1.5:
  * support for python3 and python 2.7
* Mon May 31 2010 bg@novell.com
- fix build for hppa
* Fri Jan 15 2010 aeszter@gwdg.de
- re-enable build on non-SUSE distros
- do not provide python-numeric on Fedora, since a package by that
  name exists
* Wed Jan 13 2010 lars@linux-schulserver.de
- use a more generic way to define py_sitedir on all targets
* Mon Jan 11 2010 coolo@novell.com
- remerge d:l:p version with O:F version
  - split -devel package and add support for !suse targets
* Wed Apr  8 2009 matejcik@suse.cz
- update to 1.3.0
  * official python 2.6 support (although it did (mostly)
    work before)
  * new multiarray APIs
* Wed Feb 11 2009 ro@suse.de
- fix filelist by using "--record-rpm" instead of "--record"
  (and do not quote lines starting with "%%dir ")
* Wed Feb  4 2009 matejcik@suse.cz
- package taken directly from devel:languages:python repository,
  original changelog follows:
* Tue Dec  2 2008 James Oakley <jfunk@funktronics.ca> - 1.2.1-1
- Update to 1.2.1
* Mon Aug 11 2008 James Oakley <jfunk@funktronics.ca> - 1.1.1-1
- Update to 1.1.1:
  - Python 2.3.x fixes
  * Robert Kern -- remove development branch of f2py.
  * Pierre GM -- masked array, fix dictionary update.
  * Pierre GM -- masked array, fix itertools groupby dependency.
  * Pierre GM -- masked array, fix use of iterators.
  * Neil Muller -- fix test dependency on pretty print (#828).
  - General improvements
  * David Cournapeau -- scons build fixes/improvements.
  * Stefan van der Walt -- Howto document updates.
  * Fernando Perez -- cython updates.
  * Robert Kern -- PyPI metadata fixes.
  - Bug fixes
  * #791 -- Travis Oliphant, std/var not properly calling array_finalize.
  * #798 -- Stefan van der Walt, piecewise exposes raw memory.
  * #810 -- David Huard, Verbose argument not effective for ndarrays in assert_equal.
  * #828 -- Neil Muller, numpy file format format test failures on Solaris.
  * #825 -- Neil Muller/Charles Harris, SIGBUS in UNICODE_getattr on Sparc Linux.
  * #837 -- Pauli Virtanen, Infinite loop in fromfile & fromstring
  * #841 -- Charles Harris, make numpy complex types print like Python.
  * #843 -- Michael Abbott, reference count error in PyArray_CanCoerceScalar
  * #844 -- David Cournapeau, failure with numpy inner.
  * #848 -- Michael Abbott/Charles Harris/Travis Oliphant, reference leak.
  * #849 -- Michael Abbott, reference to deallocated object.
  * #850 -- Michael Abbott, memory leak.
  * #854 -- Pauli Virtanen, Non-standard branch cuts (arccosh).
  * #857 -- Pierre GM, dividing masked array with newaxis fails.
  * ------- David Cournapeau, ctypes load_library fix.
  * ------- Ryan May, Stefan van der Walt, fix loadtxt.
  * ------- Robert Kern, make numeric.py functions return booleans.
  * ------- Robert Kern, correct old numeric typecodes.
  * ------- Robert Kern, fix raising exception in tests.
  * ------- Robert Kern, make sure Zipf results are in allowable range.
  * ------- Robert Kern, fix c++ style comment.
